export interface Cookie {
    name: string;
    value?: string;
    maxAge?: number;
    expires?: Date;
    path?: string;
    domain?: string;
    secure?: boolean;
    httpOnly?: boolean;
    sameSite?: boolean | 'strict' | 'lax';
    overwrite?: boolean;
}
export declare class Result {
    readonly status: number;
    readonly value?: unknown;
    readonly cookies?: Cookie[] | undefined;
    readonly headers?: Record<string, string> | undefined;
    readonly redirectUrl?: string | undefined;
    readonly local?: Record<string, unknown> | undefined;
    protected constructor(status: number, value?: unknown, cookies?: Cookie[] | undefined, headers?: Record<string, string> | undefined, redirectUrl?: string | undefined, local?: Record<string, unknown> | undefined);
}
/** Used primarily in data routes where we want to force a value and it not show up in the options */
export interface ResultOptionsNoValue {
    local?: Record<string, unknown>;
    cookies?: Cookie[];
    headers?: Record<string, string>;
}
export interface ResultOptionsWithValue extends ResultOptionsNoValue {
    value?: unknown;
}
export declare class DataResult extends Result {
    readonly __type: 'DATA_RESULT';
    private constructor();
    static ok(options?: ResultOptionsWithValue): DataResult;
    static error(value: unknown, options?: ResultOptionsNoValue): DataResult;
    static redirect(url: string, status?: 301 | 302, options?: ResultOptionsNoValue): DataResult;
    static notFound(options?: ResultOptionsNoValue): DataResult;
    static unauthorized(options?: ResultOptionsNoValue): DataResult;
}
export declare class ViewResult extends Result {
    readonly __type: 'VIEW_RESULT';
    readonly template?: string;
    private constructor();
    static ok(template: string, options?: ResultOptionsWithValue): ViewResult;
    static redirect(url: string, status?: 301 | 302, options?: ResultOptionsNoValue): ViewResult;
    static error(template: string, options?: ResultOptionsWithValue): ViewResult;
    static notFound(template: string, options?: ResultOptionsWithValue): ViewResult;
    static unauthorized(template: string, options?: ResultOptionsWithValue): ViewResult;
}
export declare class MiddlewareResult extends Result {
    readonly __type: 'MIDDLEWARE_RESULT';
    readonly continue: boolean;
    readonly end: boolean;
    private constructor();
    /**
     * Advances to the next middleware. To pass data along to the next middleware handler or route handler
     * set options.value. Context.local will be set to the merged values of previous Middleware.continue.
     * @param options
     */
    static continue(options?: ResultOptionsWithValue): MiddlewareResult;
    /**
     * Will end the request with the given status and setting the body to options.value. For view routes the render
     * function will be skipped so any rendering of templates would need to be done explicitly in the middleware.
     *
     * This choice is intentional to allow middleware to handle things like caching or other events that may require it to
     * end the request with some content.
     *
     * @param status
     * @param options
     */
    static end(status: number, options?: ResultOptionsWithValue): MiddlewareResult;
    static error(value: unknown, options?: ResultOptionsNoValue): MiddlewareResult;
    static redirect(url: string, status?: 301 | 302, options?: ResultOptionsNoValue): MiddlewareResult;
    static notFound(options?: ResultOptionsNoValue): MiddlewareResult;
    static unauthorized(options?: ResultOptionsNoValue): MiddlewareResult;
}
